@@ -659,7 +659,7 @@ void generate_permutation(int *buf, int n)
 	for (i=0; i<n; i++) buf[i] = i;
 	for (i=0; i<n-1; i++)
 	{
-		j = i + (int) (((double)rand()/RAND_MAX)*(n - i));
+		j = i + (int) (((double)rand()/(RAND_MAX+1.0))*(n - i));
 		int tmp = buf[i]; buf[i] = buf[j]; buf[j] = tmp;
 	}
 }
